.. include:: ../../README.rst


Documentation
-------------
.. autofunction:: tippo.get_builtin

.. autofunction:: tippo.get_typing

.. autofunction:: tippo.get_origin

.. autofunction:: tippo.get_args

.. autofunction:: tippo.get_name

.. autoclass:: tippo.GenericMeta

.. autoclass:: tippo.SupportsKeysAndGetItem
   :members: keys, __getitem__